@@ -10,9 +10,9 @@ my $timeout = 24;  # 24 hour timeout
 $timeout *= 3600;
 
 my $domain =  App::DDNS::Namecheap->new(
-                  domain   => 'website.com',
+                  domain   => 'mysite.org',
 		  password => 'abcdefghijklmnopqrstuvwxyz012345',
-		  hosts    => [ "@", "www" ],
+		  hosts    => [ "@", "www", "*" ],
 );
 
 while (1) {
@@ -30,7 +30,7 @@ update.pl - command line stub
 
 =head1 DESCRIPTION
 
-Dynamic DNS update daemon for Namecheap registered domains.
+Dynamic DNS update stub for Namecheap registered domains
 
 =head1 CAVEATS
 
